==> starplot-0.16.4.tar.gz: starplot-0.16.4/docs/examples.md <==
<div class="grid cards examples" markdown>


<ul>

    <li>
        <a href="/examples/star-chart-basic/">
            <img src="/images/examples/star_chart_basic-sm.png" alt="Basic Star Chart" class="off-glb"/>

            <p class="example-card-title">Basic Star Chart</p>
        </a>
    </li>
    <li>
        <a href="/examples/star-chart-detail/">
            <img src="/images/examples/star_chart_detail-sm.png" alt="Detailed Star Chart" class="off-glb"/>

            <p class="example-card-title">Detailed Star Chart</p>
        </a>
    </li>

    <li>
        <a href="/examples/map-orion/">
            <img src="/images/examples/map_orion-sm.png" alt="Map of Orion" class="off-glb"/>

            <p class="example-card-title">Map of Orion</p>
        </a>
    </li>

    <li>
        <a href="/examples/map-big/">
            <img src="/images/examples/map_big-sm.png" alt="Big Map" class="off-glb"/>

            <p class="example-card-title">Big Map</p>
        </a>
    </li>

    <li>
        <a href="/examples/horizon-double-cluster/">
            <img src="/images/examples/horizon_double_cluster-sm.png" alt="Finding the Double Cluster in Perseus" class="off-glb" loading="lazy"/>

            <p class="example-card-title">Finding the Double Cluster</p>
        </a>
    </li>

    <li>
        <a href="/examples/map-carina-nebula/">
            <img src="/images/examples/map_carina-sm.png" alt="Map of Carina Constellation" class="off-glb" loading="lazy"/>

            <p class="example-card-title">Carina Nebula + Clusters</p>
        </a>
    </li>

    <li>
        <a href="/examples/horizon-gradient/">
            <img src="/images/examples/horizon_gradient-sm.png" alt="Horizon Gradient Plot" class="off-glb" loading="lazy"/>

            <p class="example-card-title">Horizon Gradient</p>
        </a>
    </li>

    <li>
        <a href="/examples/optic-solar-eclipse/">
            <img src="/images/examples/optic_solar_eclipse-sm.png" alt="Total Solar Eclipse 2024" class="off-glb" loading="lazy"/>

            <p class="example-card-title">Total Solar Eclipse 2024</p>
        </a>
    </li>

    <li>
        <a href="/examples/optic-m45/">
            <img src="/images/examples/optic_m45-sm.png" alt="Optic Plot of the Pleiades" class="off-glb" loading="lazy"/>

            <p class="example-card-title">Optic Plot of the Pleiades</p>
        </a>
    </li>

    <li>
        <a href="/examples/optic-orion/">
            <img src="/images/examples/optic_orion_nebula-sm.png" alt="Optic Plot of the Orion Nebula" class="off-glb" loading="lazy"/>

            <p class="example-card-title">Optic Plot of the Orion Nebula</p>
        </a>
    </li>

    <li>
        <a href="/examples/map-milky-way-stars/">
            <img src="/images/examples/map_milky_way_stars-sm.png" alt="Stars of the Milky Way" class="off-glb"/>

            <p class="example-card-title">The Milky Way</p>
        </a>
    </li>

    <li>
        <a href="/examples/map-orthographic/">
            <img src="/images/examples/map_orthographic-sm.png" alt="Orthographic Map" class="off-glb" loading="lazy"/>

            <p class="example-card-title">Orthographic Map</p>
        </a>
    </li>

    

    <li>
        <a href="/examples/map-big-dipper/">
            <img src="/images/examples/map_big_dipper-sm.png" alt="Map of the Big Dipper" class="off-glb" loading="lazy"/>

            <p class="example-card-title">The Big Dipper</p>
        </a>
    </li>

    <!-- <li>
        <a href="/examples/map-comet-neowise/">
            <img src="/images/examples/map_comet_neowise-sm.png" alt="Map of Comet NEOWISE in 2020" class="off-glb" loading="lazy"/>

            <p class="example-card-title">Comet NEOWISE</p>
        </a>
    </li> -->

    <li>
        <a href="/examples/map-sagittarius/">
            <img src="/images/examples/map_sagittarius-sm.png" alt="Map of Sagittarius" class="off-glb" loading="lazy"/>

            <p class="example-card-title">Map of Sagittarius</p>
        </a>
    </li>

    <li>
        <a href="/examples/map-canis-major/">
            <img src="/images/examples/map_canis_major-sm.png" alt="Map of the Constellation Canis Major" class="off-glb" loading="lazy"/>

            <p class="example-card-title">Map of Canis Major</p>
        </a>
    </li>

    <li>
        <a href="/examples/map-cassiopeia/">
            <img src="/images/examples/map_cas-sm.png" alt="Map of the Constellation Cassiopeia" class="off-glb" loading="lazy"/>

            <p class="example-card-title">Map of Cassiopeia</p>
        </a>
    </li>

    

</ul>


</div>

<div class="info-panel bg-info columns-2" style="padding: 40px;">
    <a href="https://steveberardimaps.com/products/all-sky-map" target="_blank">
        <img src="/images/cover-front-sm-360.png" style="max-width: 240px; padding-right: 28px;" class="off-glb">
    </a>
    <div class="md-typeset">
        <h2 class="mt-0">Example Publication - All Sky Map</h2>
        
        <p>Starplot can create publication-quality maps, thanks to its ability to export SVG files. These files can then be imported into many design applications, including Adobe Illustrator and Affinity Publisher, to create high-quality printed maps, books, etc.</p>

        <p>One example is the <a href="https://steveberardimaps.com/products/all-sky-map" target="_blank">All Sky Map</a>, which is a foldable map designed and created by Steve Berardi (who also created Starplot!).</p>
        
        <p>The map was created by first writing code to generate SVG files of the map and then these were imported into Affinity Publisher to fine-tune some of the label positions and add the legend, supporting text, and create the overall page layout of the map. It was then printed on synthetic paper that is waterproof and tear-resistant!</p>
    
        <a href="https://steveberardimaps.com/products/all-sky-map" class="md-button" target="_blank" style="align-content: center;">
            Check it out
            <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 16 16" width="18" height="18" class="filter-blue" style="margin-left: 4px; vertical-align: text-top;"><path d="M3.75 2h3.5a.75.75 0 0 1 0 1.5h-3.5a.25.25 0 0 0-.25.25v8.5c0 .138.112.25.25.25h8.5a.25.25 0 0 0 .25-.25v-3.5a.75.75 0 0 1 1.5 0v3.5A1.75 1.75 0 0 1 12.25 14h-8.5A1.75 1.75 0 0 1 2 12.25v-8.5C2 2.784 2.784 2 3.75 2Zm6.854-1h4.146a.25.25 0 0 1 .25.25v4.146a.25.25 0 0 1-.427.177L13.03 4.03 9.28 7.78a.751.751 0 0 1-1.042-.018.751.751 0 0 1-.018-1.042l3.75-3.75-1.543-1.543A.25.25 0 0 1 10.604 1Z"></path></svg>
        </a>
    
    </div>
</div>

<br/>

Check out the [tutorial](tutorial.md) and code reference to learn more about using Starplot!
{.text-subtitle .text-center}

<br/>
<br/>

==> starplot-0.16.7.tar.gz: starplot-0.16.7/docs/examples.md <==
<div class="grid cards examples" markdown>


<ul>

    <li>
        <a href="/examples/star-chart-basic/">
            <img src="/images/examples/star_chart_basic-sm.png" alt="Basic Star Chart" class="off-glb"/>

            <p class="example-card-title">Basic Star Chart</p>
        </a>
    </li>
    <li>
        <a href="/examples/star-chart-detail/">
            <img src="/images/examples/star_chart_detail-sm.png" alt="Detailed Star Chart" class="off-glb"/>

            <p class="example-card-title">Detailed Star Chart</p>
        </a>
    </li>

    <li>
        <a href="/examples/map-orion/">
            <img src="/images/examples/map_orion-sm.png" alt="Map of Orion" class="off-glb"/>

            <p class="example-card-title">Map of Orion</p>
        </a>
    </li>

    <li>
        <a href="/examples/map-big/">
            <img src="/images/examples/map_big-sm.png" alt="Big Map" class="off-glb"/>

            <p class="example-card-title">Big Map</p>
        </a>
    </li>

    <li>
        <a href="/examples/horizon-double-cluster/">
            <img src="/images/examples/horizon_double_cluster-sm.png" alt="Finding the Double Cluster in Perseus" class="off-glb" loading="lazy"/>

            <p class="example-card-title">Finding the Double Cluster</p>
        </a>
    </li>

    <li>
        <a href="/examples/map-carina-nebula/">
            <img src="/images/examples/map_carina-sm.png" alt="Map of Carina Constellation" class="off-glb" loading="lazy"/>

            <p class="example-card-title">Carina Nebula + Clusters</p>
        </a>
    </li>

    <li>
        <a href="/examples/horizon-gradient/">
            <img src="/images/examples/horizon_gradient-sm.png" alt="Horizon Gradient Plot" class="off-glb" loading="lazy"/>

            <p class="example-card-title">Horizon Gradient</p>
        </a>
    </li>

    <li>
        <a href="/examples/optic-solar-eclipse/">
            <img src="/images/examples/optic_solar_eclipse-sm.png" alt="Total Solar Eclipse 2024" class="off-glb" loading="lazy"/>

            <p class="example-card-title">Total Solar Eclipse 2024</p>
        </a>
    </li>

    <li>
        <a href="/examples/optic-m45/">
            <img src="/images/examples/optic_m45-sm.png" alt="Optic Plot of the Pleiades" class="off-glb" loading="lazy"/>

            <p class="example-card-title">Optic Plot of the Pleiades</p>
        </a>
    </li>

    <li>
        <a href="/examples/optic-orion/">
            <img src="/images/examples/optic_orion_nebula-sm.png" alt="Optic Plot of the Orion Nebula" class="off-glb" loading="lazy"/>

            <p class="example-card-title">Optic Plot of the Orion Nebula</p>
        </a>
    </li>

    <li>
        <a href="/examples/map-milky-way-stars/">
            <img src="/images/examples/map_milky_way_stars-sm.png" alt="Stars of the Milky Way" class="off-glb"/>

            <p class="example-card-title">The Milky Way</p>
        </a>
    </li>

    <li>
        <a href="/examples/map-orthographic/">
            <img src="/images/examples/map_orthographic-sm.png" alt="Orthographic Map" class="off-glb" loading="lazy"/>

            <p class="example-card-title">Orthographic Map</p>
        </a>
    </li>

    

    <li>
        <a href="/examples/map-big-dipper/">
            <img src="/images/examples/map_big_dipper-sm.png" alt="Map of the Big Dipper" class="off-glb" loading="lazy"/>

            <p class="example-card-title">The Big Dipper</p>
        </a>
    </li>

    <!-- <li>
        <a href="/examples/map-comet-neowise/">
            <img src="/images/examples/map_comet_neowise-sm.png" alt="Map of Comet NEOWISE in 2020" class="off-glb" loading="lazy"/>

            <p class="example-card-title">Comet NEOWISE</p>
        </a>
    </li> -->

    <li>
        <a href="/examples/map-sagittarius/">
            <img src="/images/examples/map_sagittarius-sm.png" alt="Map of Sagittarius" class="off-glb" loading="lazy"/>

            <p class="example-card-title">Map of Sagittarius</p>
        </a>
    </li>

    <li>
        <a href="/examples/map-canis-major/">
            <img src="/images/examples/map_canis_major-sm.png" alt="Map of the Constellation Canis Major" class="off-glb" loading="lazy"/>

            <p class="example-card-title">Map of Canis Major</p>
        </a>
    </li>

    <li>
        <a href="/examples/map-cassiopeia/">
            <img src="/images/examples/map_cas-sm.png" alt="Map of the Constellation Cassiopeia" class="off-glb" loading="lazy"/>

            <p class="example-card-title">Map of Cassiopeia</p>
        </a>
    </li>

    
</ul>

</div>

<div class="info-panel bg-info " style="padding: 24px; width: 100%;">

    <h2 class="mt-0">See more examples @ <a href="https://starplotting.com/">Starplotting.com</a></h2>
    <p><em>Like this one that shows the path of Comet C/2025 A6 (Lemmon) in October 2025:</em></p>
    <a href="https://starplotting.com/blog/comet-c2025-a6-lemmon---october-2025/">
        <img src="https://starplotting.com/blog/2025-10-15/final.png" class="off-glb"/>
    </a>
</div>

<br/>

<div class="info-panel bg-info columns-2" style="padding: 40px;">
    <a href="https://steveberardimaps.com/products/all-sky-map" target="_blank">
        <img src="/images/cover-front-sm-360.png" style="max-width: 240px; padding-right: 28px;" class="off-glb">
    </a>
    <div class="md-typeset">
        <h2 class="mt-0">Example Publication - All Sky Map</h2>
        
        <p>Starplot can create publication-quality maps, thanks to its ability to export SVG files. These files can then be imported into many design applications, including Adobe Illustrator and Affinity Publisher, to create high-quality printed maps, books, etc.</p>

        <p>One example is the <a href="https://steveberardimaps.com/products/all-sky-map" target="_blank">All Sky Map</a>, which is a foldable map designed and created by Steve Berardi (who also created Starplot!).</p>
        
        <p>The map was created by first writing code to generate SVG files of the map and then these were imported into Affinity Publisher to fine-tune some of the label positions and add the legend, supporting text, and create the overall page layout of the map. It was then printed on synthetic paper that is waterproof and tear-resistant!</p>
    
        <a href="https://steveberardimaps.com/products/all-sky-map" class="md-button" target="_blank" style="align-content: center;">
            Check it out
            <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 16 16" width="18" height="18" class="filter-blue" style="margin-left: 4px; vertical-align: text-top;"><path d="M3.75 2h3.5a.75.75 0 0 1 0 1.5h-3.5a.25.25 0 0 0-.25.25v8.5c0 .138.112.25.25.25h8.5a.25.25 0 0 0 .25-.25v-3.5a.75.75 0 0 1 1.5 0v3.5A1.75 1.75 0 0 1 12.25 14h-8.5A1.75 1.75 0 0 1 2 12.25v-8.5C2 2.784 2.784 2 3.75 2Zm6.854-1h4.146a.25.25 0 0 1 .25.25v4.146a.25.25 0 0 1-.427.177L13.03 4.03 9.28 7.78a.751.751 0 0 1-1.042-.018.751.751 0 0 1-.018-1.042l3.75-3.75-1.543-1.543A.25.25 0 0 1 10.604 1Z"></path></svg>
        </a>
    
    </div>
</div>

<br/>

Check out the [tutorial](tutorial.md) and code reference to learn more about using Starplot!
{.text-subtitle .text-center}

<br/>
<br/>
